==> estateplat-common-1.2.3-20180316.074822-45-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXtQy.java <==
/**
 * 
 */
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * @author wangtao
 * @version  2016年4月20日
 * @description 企业信息属性
 */
@Table(name = "bdc_xt_qy")
public class BdcXtQy implements Serializable{
	@Id
	private String qyid;//企业ID
	private String qymc;//企业名称
	private String zjlx;//证件编类型
	private String zjbh;//证件编号
	private String bz;//备注
	private String txdz;//通讯地址
	private String yb;//邮编
	private String fzr;//负责人
	private String fzrlxdh;//负责人联系电话
	private String dwdm;//单位代码
	private String dwxz;//单位性质
	private String fddbr;//法定代表人


	public String getDwdm() {
		return dwdm;
	}

	public void setDwdm(String dwdm) {
		this.dwdm = dwdm;
	}

	public String getTxdz() {
		return txdz;
	}

	public void setTxdz(String txdz) {
		this.txdz = txdz;
	}

	public String getYb() {
		return yb;
	}

	public void setYb(String yb) {
		this.yb = yb;
	}

	public String getFzr() {
		return fzr;
	}

	public void setFzr(String fzr) {
		this.fzr = fzr;
	}

	public String getFzrlxdh() {
		return fzrlxdh;
	}

	public void setFzrlxdh(String fzrlxdh) {
		this.fzrlxdh = fzrlxdh;
	}

	public String getQyid() {
		return qyid;
	}
	
	public void setQyid(String qyid) {
		this.qyid = qyid;
	}
	
	public String getQymc() {
		return qymc;
	}
	
	public void setQymc(String qymc) {
		this.qymc = qymc;
	}
	
	public String getZjlx() {
		return zjlx;
	}
	
	public void setZjlx(String zjlx) {
		this.zjlx = zjlx;
	}
	
	public String getZjbh() {
		return zjbh;
	}
	
	public void setZjbh(String zjbh) {
		this.zjbh = zjbh;
	}
	
	public String getBz() {
		return bz;
	}
	
	public void setBz(String bz) {
		this.bz = bz;
	}

	public String getDwxz() {
		return dwxz;
	}

	public void setDwxz(String dwxz) {
		this.dwxz = dwxz;
	}

	public String getFddbr() {
		return fddbr;
	}

	public void setFddbr(String fddbr) {
		this.fddbr = fddbr;
	}
}

==> estateplat-common-1.2.4-20200517.010423-347-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXtQy.java <==
/**
 * 
 */
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * @author wangtao
 * @version  2016年4月20日
 * @description 企业信息属性
 */
@Table(name = "bdc_xt_qy")
public class BdcXtQy implements Serializable{
	@Id
	private String qyid;//企业ID
	private String qymc;//企业名称
	private String zjlx;//证件编类型
	private String zjbh;//证件编号
	private String bz;//备注
	private String txdz;//通讯地址
	private String yb;//邮编
	private String fzr;//负责人
	private String fzrlxdh;//负责人联系电话
	private String dwdm;//单位代码
	private String dwxz;//单位性质
	private String fddbr;//法定代表人
	private String tyshxydm;//统一社会信用代码
	private String sfxwqy;//是否小微企业

	public String getDwdm() {
		return dwdm;
	}

	public void setDwdm(String dwdm) {
		this.dwdm = dwdm;
	}

	public String getTxdz() {
		return txdz;
	}

	public void setTxdz(String txdz) {
		this.txdz = txdz;
	}

	public String getYb() {
		return yb;
	}

	public void setYb(String yb) {
		this.yb = yb;
	}

	public String getFzr() {
		return fzr;
	}

	public void setFzr(String fzr) {
		this.fzr = fzr;
	}

	public String getFzrlxdh() {
		return fzrlxdh;
	}

	public void setFzrlxdh(String fzrlxdh) {
		this.fzrlxdh = fzrlxdh;
	}

	public String getQyid() {
		return qyid;
	}
	
	public void setQyid(String qyid) {
		this.qyid = qyid;
	}
	
	public String getQymc() {
		return qymc;
	}
	
	public void setQymc(String qymc) {
		this.qymc = qymc;
	}
	
	public String getZjlx() {
		return zjlx;
	}
	
	public void setZjlx(String zjlx) {
		this.zjlx = zjlx;
	}
	
	public String getZjbh() {
		return zjbh;
	}
	
	public void setZjbh(String zjbh) {
		this.zjbh = zjbh;
	}
	
	public String getBz() {
		return bz;
	}
	
	public void setBz(String bz) {
		this.bz = bz;
	}

	public String getDwxz() {
		return dwxz;
	}

	public void setDwxz(String dwxz) {
		this.dwxz = dwxz;
	}

	public String getFddbr() {
		return fddbr;
	}

	public void setFddbr(String fddbr) {
		this.fddbr = fddbr;
	}

	public String getTyshxydm() {
		return tyshxydm;
	}

	public void setTyshxydm(String tyshxydm) {
		this.tyshxydm = tyshxydm;
	}

	public String getSfxwqy() {
		return sfxwqy;
	}

	public void setSfxwqy(String sfxwqy) {
		this.sfxwqy = sfxwqy;
	}
}
